
---
# Charger 11 click

> Charger 11 Click is a LiFePO4 (lithium iron phosphate) battery charger. This click can be used for Low-Cost LiFePO4 battery chargers, or Power Tools, toys, backup energy storage solutions, etc. Charger 11 is based on MCP73123T controller which has some extra features enabling charging without too much hassle. This click board has charging current control which uses SPI interface through MCP4161 IC, which is an 8-bit digital potentiometer.

<p align="center">
  <img src="https://download.mikroe.com/images/click_for_ide/charger11_click.png" height=300px>
</p>

[click Product page](https://www.mikroe.com/charger-11-click)

---


#### Click library

- **Author**        : Stefan Ilic
- **Date**          : Aug 2021.
- **Type**          : I2C/SPI type


# Software Support

We provide a library for the Charger11 Click
as well as a demo application (example), developed using MikroElektronika
[compilers](https://www.mikroe.com/necto-studio).
The demo can run on all the main MikroElektronika [development boards](https://www.mikroe.com/development-boards).

Package can be downloaded/installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

## Library Description

> This library contains API for Charger11 Click driver.

#### Standard key functions :

- `charger11_cfg_setup` Config Object Initialization function.
```c
void charger11_cfg_setup ( charger11_cfg_t *cfg );
```

- `charger11_init` Initialization function.
```c
err_t charger11_init ( charger11_t *ctx, charger11_cfg_t *cfg );
```

#### Example key functions :

- `charger11_spi_increment_wiper` Charger 11 incrementing wiper position.
```c
void charger11_spi_increment_wiper( charger11_t *ctx );
```

- `charger11_spi_decrement_wiper` Charger 11 decrementing wiper position.
```c
void charger11_spi_decrement_wiper( charger11_t *ctx );
```

- `charger11_i2c_get_volt` Charger 11 getting output voltage.
```c
float charger11_i2c_get_volt( charger11_t *ctx, float reference_voltage );
```

## Example Description

> This is an example that demonstrates the use of the Charger 11 Click board.

**The demo application is composed of two sections :**

### Application Init

> Initalizes INT ( ST ), PWM ( LG ), AN ( LR ) pins and SPI, I2C, LOG modules.

```c

void application_init ( void ) {
    log_cfg_t log_cfg;  /**< Logger config object. */
    charger11_cfg_t charger11_cfg;  /**< Click config object. */

    /** 
     * Logger initialization.
     * Default baud rate: 115200
     * Default log level: LOG_LEVEL_DEBUG
     * @note If USB_UART_RX and USB_UART_TX 
     * are defined as HAL_PIN_NC, you will 
     * need to define them manually for log to work. 
     * See @b LOG_MAP_USB_UART macro definition for detailed explanation.
     */
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, " Application Init " );

    // Click initialization.
    charger11_cfg_setup( &charger11_cfg );
    CHARGER11_MAP_MIKROBUS( charger11_cfg, MIKROBUS_1 );
    err_t init_flag  = charger11_init( &charger11, &charger11_cfg );
    if ( ( I2C_MASTER_ERROR == init_flag ) || ( SPI_MASTER_ERROR == init_flag ) ) {
        log_error( &logger, " Application Init Error. " );
        log_info( &logger, " Please, run program again... " );

        for ( ; ; );
    }
    
    log_info( &logger, " Application Task " );
    charger11_case_report( &charger11 );
}

```

### Application Task

> Waits for user input in order to increment, decrement wiper or log report (Wiper position and Output voltage)

```c

void application_task ( void ) {
    char uart_char;
    if ( log_read( &logger, &uart_char, 1 ) ) {
        switch (uart_char) {
            case '+' : {
                charger11_case_plus( &charger11 );
                break;
            }
            case '-' : {
                charger11_case_minus( &charger11 );
                break;
            }
            case 'r' : {
                charger11_case_report( &charger11 );
                break;
            }
            default : {
                log_printf( &logger, "> Invalid command \r\n" );
                break;
            }
        }
    }
}

```


The full application code, and ready to use projects can be installed directly from *NECTO Studio Package Manager*(recommended way), downloaded from our [LibStock&trade;](https://libstock.mikroe.com) or found on [Mikroe github account](https://github.com/MikroElektronika/mikrosdk_click_v2/tree/master/clicks).

**Other Mikroe Libraries used in the example:**

- MikroSDK.Board
- MikroSDK.Log
- Click.Charger11

**Additional notes and informations**

Depending on the development board you are using, you may need
[USB UART click](https://www.mikroe.com/usb-uart-click),
[USB UART 2 Click](https://www.mikroe.com/usb-uart-2-click) or
[RS232 Click](https://www.mikroe.com/rs232-click) to connect to your PC, for
development systems with no UART to USB interface available on the board. UART
terminal is available in all MikroElektronika
[compilers](https://shop.mikroe.com/compilers).

---
